<html>
<header>
<title> Aggiorna il database php-residence </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "aggiorna.php";

$molto_vecchio = @is_file("./datipermanenti/connessione_db.inc");
$vecchio = @is_file("./dati/connessione_db.php");
if ($molto_vecchio) {
include ("./datipermanenti/connessione_db.inc");
$PHPR_DB_TYPE = "postgresql";
$PHPR_TAB_PRE = "";
include("./includes/funzioni_$PHPR_DB_TYPE.php");
} # fine if ($molto_vecchio)
else {
if ($vecchio) {
include ("./dati/connessione_db.php");
$PHPR_DB_TYPE = "postgresql";
$PHPR_TAB_PRE = "";
include("./includes/funzioni_$PHPR_DB_TYPE.php");
} # fine if ($vecchio)
else {
include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
} # fine else if ($vecchio)
} # fine else if ($molto_vecchio)

include ("./includes/funzioni.php");
include("./dati/lingua.php");
if (@is_array($lingua)) $lingua_mex = $lingua[1];
else $lingua_mex = $lingua;


$versione_corrente = @esegui_query("select * from ".$PHPR_TAB_PRE."versioni where idversioni = 1");

#esegui_query("begin");
#esegui_query("lock table anni");
$anni = esegui_query("select * from ".$PHPR_TAB_PRE."anni order by idanni");
$num_anni = numlin_query($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_mostra = risul_query($anni,$num1,idanni);
$tableprenota = $PHPR_TAB_PRE."prenota".$anno_mostra;
#pg_exec("lock table $tableprenota");
} # fine for $num1


if (!$versione_corrente) {
pg_exec("create table versioni (idversioni integer primary key, num_versione float4)");
pg_exec("lock table versioni");
pg_exec("insert into versioni (idversioni, num_versione) values (1, '0.1')");
$versione_corrente = "0.1";
} # fine if (!$versione_corrente)
else {
#pg_exec("lock table versioni");
#$versione_corrente = esegui_query("select * from versioni where idversioni = 1");
$versione_corrente = risul_query($versione_corrente,0,num_versione);
} # fine else if (!$versione_corrente)

if ($versione_corrente < "0.12") {
$aggiornato = "SI";
} # fine if ($versione_corrente < "0.12")

# c' scitto 0.19 ma in realt  la 0.2
if ($versione_corrente < "0.19") {
$aggiornato = "SI";
pg_exec("lock table appartamenti");
pg_exec("alter table appartamenti add column commento text");
rename("datipermanenti/connessione_db.inc","datipermanenti/connessione_db.php");
rename("datipermanenti/selectappartamenti.inc","datipermanenti/selectappartamenti.php");
$anni = pg_exec("select * from anni order by idanni");
$num_anni = pg_numrows($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_cambia = pg_result($anni,$num1,idanni);
rename("$anno_cambia/selectperiodi.inc","$anno_cambia/selectperiodi.php");
} # fine for $num1
pg_exec("insert into versioni (idversioni, num_versione) values (2, '100')");
$fileaperto = fopen("datipermanenti/lingua.php","a+");
fwrite($fileaperto,"<?php
\$lingua = \"ita\";
?>");
fclose($fileaperto);
pg_exec("alter table anni add column tipo_periodi text");
$anni = pg_exec("select * from anni order by idanni");
pg_exec("update anni set tipo_periodi = 's'");
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_mostra = pg_result($anni,$num1,idanni);
$tableprenota = prenota. $anno_mostra;
pg_exec("alter table $tableprenota add column conferma varchar(4)");
$tableregole = regole. $anno_mostra;
pg_exec("lock table $tableregole");
pg_exec("alter table $tableregole add column tariffa_per_app text");
pg_exec("alter table $tableregole add column motivazione text");
$tablesoldi = soldi. $anno_mostra;
pg_exec("create table $tablesoldi (idsoldi serial, motivazione text, saldo_prenota float8, saldo_cassa float8, soldi_prima float8, data_inserimento datetime)");
pg_exec("lock table $tablesoldi");
pg_exec("insert into $tablesoldi (motivazione,soldi_prima) values ('soldi_prenotazioni_cancellate','0')");
} # fine for $num1
pg_exec("create table personalizza (idpersonalizza text primary key, valpersonalizza text, valpersonalizza_num integer)");
pg_exec("lock table personalizza");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza) values ('col_tab_tutte_prenota','ca#@&pa#@&ap#@&pe#@&co')");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza) values ('valuta','Euro')");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza) values ('stile_soldi','europa')");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza) values ('costi_agg_in_tab_prenota','')");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_linee_tab2_prenota','30')");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza) values ('nomi_contratti','')");
# cambio idappartamenti da integer a text in appartamenti, $tableprenota e $tableregole
pg_exec("alter table appartamenti rename to appart");
pg_exec("drop index appartamenti_pkey");
pg_exec("alter table appart rename column idappartamenti to idappart");
pg_exec("alter table appart add column idappartamenti text");
$appartamenti = pg_exec("select * from appart");
$num_appartamenti = pg_numrows($appartamenti);
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$idapp = pg_result($appartamenti,$num1,idappart);
pg_exec("update appart set idappartamenti = '$idapp' where idappart = '$idapp'");
} # fine for $num1
pg_exec("create table appartamenti ( idappartamenti text primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, commento text )");
pg_exec("insert into appartamenti select idappartamenti,numpiano,maxoccupanti,numcasa,app_vicini,priorita,commento from appart");
pg_exec("drop table appart");
$anni = pg_exec("select * from anni order by idanni");
$num_anni = pg_numrows($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_cambia = pg_result($anni,$num1,idanni);
$tableprenota = prenota . $anno_cambia;
$tableprenota_temp = pren . $anno_cambia;
pg_exec("alter table $tableprenota rename to $tableprenota_temp");
pg_exec("drop index $tableprenota"."_pkey");
pg_exec("alter table $tableprenota_temp rename column idappartamenti to idappart");
pg_exec("alter table $tableprenota_temp add column idappartamenti text");
pg_exec("alter table $tableprenota_temp rename column sconto to scon");
pg_exec("alter table $tableprenota_temp add column sconto float8");
pg_exec("alter table $tableprenota_temp rename column tariffa_tot to tariffa_t");
pg_exec("alter table $tableprenota_temp add column tariffa_tot float8");
pg_exec("alter table $tableprenota_temp rename column caparra to capar");
pg_exec("alter table $tableprenota_temp add column caparra float8");
pg_exec("alter table $tableprenota_temp rename column pagato to paga");
pg_exec("alter table $tableprenota_temp add column pagato float8");
$prenotazioni = pg_exec("select * from $tableprenota_temp");
$num_prenotazioni = pg_numrows($prenotazioni);
for ($num2 = 0 ; $num2 < $num_prenotazioni ; $num2 = $num2 + 1) {
$idprenota = pg_result($prenotazioni,$num2,idprenota);
$idapp = pg_result($prenotazioni,$num2,idappart);
$scon = pg_result($prenotazioni,$num2,scon);
$tariffa_t = pg_result($prenotazioni,$num2,tariffa_t);
$capar = pg_result($prenotazioni,$num2,capar);
$paga = pg_result($prenotazioni,$num2,paga);
pg_exec("update $tableprenota_temp set idappartamenti = '$idapp' where idprenota = '$idprenota'");
pg_exec("update $tableprenota_temp set sconto = '$scon' where idprenota = '$idprenota'");
pg_exec("update $tableprenota_temp set tariffa_tot = '$tariffa_t' where idprenota = '$idprenota'");
pg_exec("update $tableprenota_temp set caparra = '$capar' where idprenota = '$idprenota'");
pg_exec("update $tableprenota_temp set pagato = '$paga' where idprenota = '$idprenota'");
} # fine for $num2
pg_exec("create table $tableprenota (idprenota integer primary key, idclienti integer, idappartamenti text, iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text, tariffa text, costiaggiuntivi text, sconto float8, tariffa_tot float8, caparra float8, pagato float8, commento text, conferma varchar(4), datainserimento datetime, hostinserimento varchar(50), data_modifica datetime )");
pg_exec("insert into $tableprenota select idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna,tariffa,costiaggiuntivi,sconto,tariffa_tot,caparra,pagato,commento,conferma,datainserimento,hostinserimento,data_modifica from $tableprenota_temp");
pg_exec("drop table $tableprenota_temp");
$tableregole = regole . $anno_cambia;
$tableregole_temp = reg . $anno_cambia;
pg_exec("alter table $tableregole rename to $tableregole_temp");
pg_exec("alter table $tableregole_temp rename column app_agenzia to app_ag");
pg_exec("alter table $tableregole_temp add column app_agenzia text");
$regole = pg_exec("select * from $tableregole_temp");
$num_regole = pg_numrows($regole);
for ($num2 = 0 ; $num2 < $num_regole ; $num2 = $num2 + 1) {
$idregole = pg_result($regole,$num2,idregole);
$app_ag = pg_result($regole,$num2,app_ag);
pg_exec("update $tableregole_temp set app_agenzia = '$app_ag' where idregole = '$idregole'");
} # fine for $num2
pg_exec("create table $tableregole (idregole integer, app_agenzia text, tariffa_per_app text, iddatainizio integer, iddatafine integer, motivazione text)");
pg_exec("insert into $tableregole select idregole,app_agenzia,tariffa_per_app,iddatainizio,iddatafine,motivazione from $tableregole_temp");
pg_exec("drop table $tableregole_temp");
$tablenometariffe = ntariffe . $anno_cambia;
$tablenometariffe_temp = ntarif . $anno_cambia;
pg_exec("alter table $tablenometariffe rename to $tablenometariffe_temp ");
pg_exec("alter table $tablenometariffe_temp rename column costosettimanale to costosett");
pg_exec("alter table $tablenometariffe_temp add column costosettimanale float8");
pg_exec("alter table $tablenometariffe_temp rename column costofinale to costofin");
pg_exec("alter table $tablenometariffe_temp add column costofinale float8");
pg_exec("alter table $tablenometariffe_temp rename column costop_arrotond to costop_arr");
pg_exec("alter table $tablenometariffe_temp add column costop_arrotond float8");
pg_exec("alter table $tablenometariffe_temp rename column caparra_arrotond to caparra_arr");
pg_exec("alter table $tablenometariffe_temp add column caparra_arrotond float8");
$nomitariffe = pg_exec("select * from $tablenometariffe_temp");
$num_nomitariffe = pg_numrows($nomitariffe);
for ($num2 = 0 ; $num2 < $num_nomitariffe ; $num2 = $num2 + 1) {
$idntariffe = pg_result($nomitariffe,$num2,idntariffe);
$costosett = pg_result($nomitariffe,$num2,costosett);
$costofin = pg_result($nomitariffe,$num2,costofin);
$costop_arr = pg_result($nomitariffe,$num2,costop_arr);
$caparra_arr = pg_result($nomitariffe,$num2,caparra_arr);
pg_exec("update $tablenometariffe_temp set costosettimanale = '$costosett' where idntariffe = '$idntariffe'");
pg_exec("update $tablenometariffe_temp set costofinale = '$costofin' where idntariffe = '$idntariffe'");
pg_exec("update $tablenometariffe_temp set costop_arrotond = '$costop_arr' where idntariffe = '$idntariffe'");
pg_exec("update $tablenometariffe_temp set caparra_arrotond = '$caparra_arr' where idntariffe = '$idntariffe'");
} # fine for $num2
pg_exec("create table $tablenometariffe (idntariffe integer, tariffa1 varchar(40), tariffa2 varchar(40), tariffa3 varchar(40), tariffa4 varchar(40), tariffa5 varchar(40), tariffa6 varchar(40), tariffa7 varchar(40), tariffa8 varchar(40), tariffa9 varchar(40), tariffa10 varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40), caparra_percent integer, caparra_arrotond float8 )");
pg_exec("insert into $tablenometariffe select idntariffe,tariffa1,tariffa2,tariffa3,tariffa4,tariffa5,tariffa6,tariffa7,tariffa8,tariffa9,tariffa10,costosettimanale,costofinale,costopercentuale,costop_arrotond,regole,caparra_percent,caparra_arrotond from $tablenometariffe_temp");
pg_exec("drop table $tablenometariffe_temp");
$tableperiodi = periodi . $anno_cambia;
$tableperiodi_temp = perio . $anno_cambia;
pg_exec("drop index $tableperiodi"."_pkey");
pg_exec("alter table $tableperiodi rename to $tableperiodi_temp ");
pg_exec("alter table $tableperiodi_temp rename column tariffa1 to tari1");
pg_exec("alter table $tableperiodi_temp add column tariffa1 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa2 to tari2");
pg_exec("alter table $tableperiodi_temp add column tariffa2 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa3 to tari3");
pg_exec("alter table $tableperiodi_temp add column tariffa3 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa4 to tari4");
pg_exec("alter table $tableperiodi_temp add column tariffa4 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa5 to tari5");
pg_exec("alter table $tableperiodi_temp add column tariffa5 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa6 to tari6");
pg_exec("alter table $tableperiodi_temp add column tariffa6 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa7 to tari7");
pg_exec("alter table $tableperiodi_temp add column tariffa7 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa8 to tari8");
pg_exec("alter table $tableperiodi_temp add column tariffa8 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa9 to tari9");
pg_exec("alter table $tableperiodi_temp add column tariffa9 float8");
pg_exec("alter table $tableperiodi_temp rename column tariffa10 to tari10");
pg_exec("alter table $tableperiodi_temp add column tariffa10 float8");
$periodi = pg_exec("select * from $tableperiodi_temp");
$num_periodi = pg_numrows($periodi);
for ($num2 = 0 ; $num2 < $num_periodi ; $num2 = $num2 + 1) {
$idperiodi = pg_result($periodi,$num2,idperiodi);
$tari1 = pg_result($periodi,$num2,tari1);
$tari2 = pg_result($periodi,$num2,tari2);
$tari3 = pg_result($periodi,$num2,tari3);
$tari4 = pg_result($periodi,$num2,tari4);
$tari5 = pg_result($periodi,$num2,tari5);
$tari6 = pg_result($periodi,$num2,tari6);
$tari7 = pg_result($periodi,$num2,tari7);
$tari8 = pg_result($periodi,$num2,tari8);
$tari9 = pg_result($periodi,$num2,tari9);
$tari10 = pg_result($periodi,$num2,tari10);
pg_exec("update $tableperiodi_temp set tariffa1 = '$tari1' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa2 = '$tari2' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa3 = '$tari3' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa4 = '$tari4' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa5 = '$tari5' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa6 = '$tari6' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa7 = '$tari7' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa8 = '$tari8' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa9 = '$tari9' where idperiodi = '$idperiodi'");
pg_exec("update $tableperiodi_temp set tariffa10 = '$tari10' where idperiodi = '$idperiodi'");
} # fine for $num2
pg_exec("create table $tableperiodi (idperiodi integer primary key, datainizio date not null, datafine date, tariffa1 float8, tariffa2 float8, tariffa3 float8, tariffa4 float8, tariffa5 float8, tariffa6 float8, tariffa7 float8, tariffa8 float8, tariffa9 float8, tariffa10 float8)");
pg_exec("insert into $tableperiodi select idperiodi,datainizio,datafine,tariffa1,tariffa2,tariffa3,tariffa4,tariffa5,tariffa6,tariffa7,tariffa8,tariffa9,tariffa10 from $tableperiodi_temp");
pg_exec("drop table $tableperiodi_temp");
$tablecosti = costi . $anno_cambia;
$tablecosti_temp = cos . $anno_cambia;
pg_exec("drop index $tablecosti"."_idcosti_key");
pg_exec("alter table $tablecosti rename to $tablecosti_temp ");
pg_exec("alter table $tablecosti_temp rename column val_costo to val_cos");
pg_exec("alter table $tablecosti_temp add column val_costo float8");
$costi = pg_exec("select * from $tablecosti_temp");
$num_costi = pg_numrows($costi);
for ($num2 = 0 ; $num2 < $num_costi ; $num2 = $num2 + 1) {
$idcosti = pg_result($costi,$num2,idcosti);
$val_cos = pg_result($costi,$num2,val_cos);
pg_exec("update $tablecosti_temp set val_costo = '$val_cos' where idcosti = '$idcosti'");
} # fine for $num2
pg_exec("create table $tablecosti (idcosti integer unique,nome_costo text, val_costo float8, persona_costo text, provenienza_costo text, tipo_costo text, datainserimento datetime, hostinserimento varchar(50))");
pg_exec("insert into $tablecosti select idcosti,nome_costo,val_costo,persona_costo,provenienza_costo,tipo_costo,datainserimento,hostinserimento from $tablecosti_temp");
pg_exec("drop table $tablecosti_temp");
} # fine for $num1
rename ("datipermanenti","dati");
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_mostra = pg_result($anni,$num1,idanni);
copy("$anno_mostra/selectperiodi.php","dati/selectperiodi$anno_mostra.php");
unlink("$anno_mostra/selectperiodi.php");
rmdir("$anno_mostra");
} # fine for $num1
} # fine if ($versione_corrente < "0.19")
else {
#pg_exec("lock table appartamenti");
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_mostra = risul_query($anni,$num1,idanni);
$tableregole = regole. $anno_mostra;
#pg_exec("lock table $tableregole");
$tablesoldi = soldi. $anno_mostra;
#pg_exec("lock table $tablesoldi");
} # fine for $num1
#pg_exec("lock table personalizza");
} # fine else if ($versione_corrente < "0.19")

if ($versione_corrente < "0.21") {
$aggiornato = "SI";
$anni = pg_exec("select * from anni order by idanni");
$num_anni = pg_numrows($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_cambia = pg_result($anni,$num1,idanni);
copy ("dati/selectperiodi$anno_cambia.php","dati/selperiodimenu$anno_cambia.php");
} # fine for $num1
} # fine if ($versione_corrente < "0.21")

if ($versione_corrente < "0.22") {
$aggiornato = "SI";
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','0')");
} # fine if ($versione_corrente < "0.22")

if ($versione_corrente < "0.23") {
$aggiornato = "SI";
} # fine if ($versione_corrente < "0.23")

if ($versione_corrente < "0.24") {
$aggiornato = "SI";
} # fine if ($versione_corrente < "0.24")

if ($versione_corrente < "0.30") {
$aggiornato = "SI";
$anni = pg_exec("select * from anni order by idanni");
$num_anni = pg_numrows($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_cambia = pg_result($anni,$num1,idanni);
$tablenometariffe = ntariffe . $anno_cambia;
$tablenometariffe_temp = ntar . $anno_cambia;
pg_exec("alter table $tablenometariffe rename to $tablenometariffe_temp ");
$riga_ntariffe = pg_exec("select * from $tablenometariffe_temp where idntariffe = 1");
$caparra_percent = pg_result($riga_ntariffe,0,caparra_percent);
$caparra_arrotond = pg_result($riga_ntariffe,0,caparra_arrotond);
pg_exec("create table $tablenometariffe (idntariffe integer, nomecostoagg varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40), tariffa1 varchar(40), tariffa2 varchar(40), tariffa3 varchar(40), tariffa4 varchar(40), tariffa5 varchar(40), tariffa6 varchar(40), tariffa7 varchar(40), tariffa8 varchar(40), tariffa9 varchar(40), tariffa10 varchar(40) )");
pg_exec("insert into $tablenometariffe (idntariffe,costosettimanale,costofinale,costopercentuale,costop_arrotond,regole,tariffa1,tariffa2,tariffa3,tariffa4,tariffa5,tariffa6,tariffa7,tariffa8,tariffa9,tariffa10) select idntariffe,costosettimanale,costofinale,costopercentuale,costop_arrotond,regole,tariffa1,tariffa2,tariffa3,tariffa4,tariffa5,tariffa6,tariffa7,tariffa8,tariffa9,tariffa10 from $tablenometariffe_temp");
pg_exec("drop table $tablenometariffe_temp");
pg_exec("update $tablenometariffe set nomecostoagg = 10 where idntariffe = 1");
$idntariffe = pg_exec("select max(idntariffe) from $tablenometariffe");
$idntariffe = pg_result($idntariffe,0,max) + 1;
$num_spostamenti = 3;
if ($idntariffe < 4) $num_spostamenti = $idntariffe - 1;
for ($num2 = $idntariffe ; $num2 <= 3 ; $num2++) {
pg_exec("insert into $tablenometariffe (idntariffe) values ('$num2')");
$idntariffe++;
} # fine for $num2
for ($num2 = 2 ; $num2 <= $num_spostamenti ; $num2++) {
$riga_ntariffe = pg_exec("select * from $tablenometariffe where idntariffe = '$num2'");
if (pg_numrows($riga_ntariffe) != 0) {
$tariffa1 = pg_result($riga_ntariffe,0,tariffa1);
$costosettimanale = pg_result($riga_ntariffe,0,costosettimanale);
$costofinale = pg_result($riga_ntariffe,0,costofinale);
$costopercentuale = pg_result($riga_ntariffe,0,costopercentuale);
$costop_arrotond = pg_result($riga_ntariffe,0,costop_arrotond);
$regole = pg_result($riga_ntariffe,0,regole);
pg_exec("insert into $tablenometariffe (idntariffe) values ('$idntariffe') ");
if ($tariffa1) pg_exec("update $tablenometariffe set tariffa1 = '$tariffa1' where idntariffe = '$idntariffe'");
if ($costosettimanale) pg_exec("update $tablenometariffe set costosettimanale = '$costosettimanale' where idntariffe = '$idntariffe'");
if ($costofinale) pg_exec("update $tablenometariffe set costofinale = '$costofinale' where idntariffe = '$idntariffe'");
if ($costopercentuale) pg_exec("update $tablenometariffe set costopercentuale = '$costopercentuale' where idntariffe = '$idntariffe'");
if ($costop_arrotond) pg_exec("update $tablenometariffe set costop_arrotond = '$costop_arrotond' where idntariffe = '$idntariffe'");
if ($regole) pg_exec("update $tablenometariffe set regole = '$regole' where idntariffe = '$idntariffe'");
$idntariffe++;
pg_exec("delete from $tablenometariffe where idntariffe = '$num2'");
} # fine if (pg_numrows($riga_ntariffe) != 0)
pg_exec("insert into $tablenometariffe (idntariffe) values ('$num2')");
} # fine for $num2
for ($num2 = 1 ; $num2 <= 10 ; $num2++) {
$tariffa = "tariffa".$num2;
pg_exec("update $tablenometariffe set $tariffa = '$caparra_percent' where idntariffe = 2");
pg_exec("update $tablenometariffe set $tariffa = '$caparra_arrotond' where idntariffe = 3");
} # fine for $num2
for ($num2 = 4 ; $num2 < $idntariffe ; $num2++) {
$riga_ntariffe = pg_exec("select * from $tablenometariffe where idntariffe = '$num2'");
if (pg_numrows($riga_ntariffe) != 0) {
$tariffa1 = pg_result($riga_ntariffe,0,tariffa1);
pg_exec("update $tablenometariffe set nomecostoagg = '$tariffa1' where idntariffe = '$num2'");
pg_exec("update $tablenometariffe set tariffa1 = '' where idntariffe = '$num2'");
$regole = pg_exec("select regole from $tablenometariffe where idntariffe = '$num2'");
$regole = pg_result($regole,0,regole);
if (substr($regole,0,1) == "s") {
for ($num3 = 1 ; $num3 <= 10 ; $num3++) {
$tariffa = "tariffa".$num3;
pg_exec("update $tablenometariffe set $tariffa = '1' where idntariffe = '$num2'");
} # fine for $num3
} # fine if (substr($regole,0,1) == "s")
} # fine if (pg_numrows($riga_ntariffe) != 0)
} # fine for $num2
$righe_costi_agg = pg_exec("select * from $tablenometariffe where idntariffe > 3");
for ($num2 = 0 ; $num2 < pg_numrows($righe_costi_agg) ; $num2++) {
$nome_costo_agg = pg_result($righe_costi_agg,$num2,nomecostoagg);
if (!$nome_costo_agg) {
$idntariffe = pg_result($righe_costi_agg,$num2,idntariffe);
pg_exec("delete from $tablenometariffe where idntariffe = '$idntariffe'");
} # fine if (!$nome_costo_agg)
} # fine for $num2
pg_exec("update $tablenometariffe set costosettimanale = NULL,costofinale = NULL,costopercentuale = NULL where idntariffe < 4");
} # fine for $num1
$linee_conn = file("./dati/connessione_db.php");
$PHPR_LOAD_EXT = "NO";
for ($num1 = 0 ; $num1 < count($linee_conn) ; $num1++) {
$linea = $linee_conn[$num1];
if (substr($linea,0,15) == "\$numconnessione") {
$linea = explode("=",$linea);
for ($num2 = 0 ; $num2 < count($linea) ; $num2++) {
if (substr($linea[$num2],-6) ==  "dbname" or substr($linea[$num2],-7) ==  "dbname ") {
$parte = explode(" ",$linea[$num2+1]);
for ($num3 = 0 ; $num3 < count($parte) ; $num3++) {
if ($parte[$num3] != "") {
$PHPR_DB_NAME = str_replace("\"","",$parte[$num3]);
$PHPR_DB_NAME = str_replace("\'","",$PHPR_DB_NAME);
break;
} # fine if ($parte[$num3] != "")
} # fine for $num3
} # fine if (substr($linea[$num2],-6) ==  "dbname" or...)
if (substr($linea[$num2],-4) ==  "host" or substr($linea[$num2],-5) ==  "host ") {
$parte = explode(" ",$linea[$num2+1]);
for ($num3 = 0 ; $num3 < count($parte) ; $num3++) {
if ($parte[$num3] != "") {
$PHPR_DB_HOST = str_replace("\"","",$parte[$num3]);
$PHPR_DB_HOST = str_replace("\'","",$PHPR_DB_HOST);
break;
} # fine if ($parte[$num3] != "")
} # fine for $num3
} # fine if (substr($linea[$num2],-4) ==  "host" or...)
if (substr($linea[$num2],-4) ==  "port" or substr($linea[$num2],-5) ==  "port ") {
$parte = explode(" ",$linea[$num2+1]);
for ($num3 = 0 ; $num3 < count($parte) ; $num3++) {
if ($parte[$num3] != "") {
$PHPR_DB_PORT = str_replace("\"","",$parte[$num3]);
$PHPR_DB_PORT = str_replace("\'","",$PHPR_DB_PORT);
break;
} # fine if ($parte[$num3] != "")
} # fine for $num3
} # fine if (substr($linea[$num2],-4) ==  "port" or...)
if (substr($linea[$num2],-4) ==  "user" or substr($linea[$num2],-5) ==  "user ") {
$parte = explode(" ",$linea[$num2+1]);
for ($num3 = 0 ; $num3 < count($parte) ; $num3++) {
if ($parte[$num3] != "") {
$PHPR_DB_USER = str_replace("\"","",$parte[$num3]);
$PHPR_DB_USER = str_replace("\'","",$PHPR_DB_USER);
break;
} # fine if ($parte[$num3] != "")
} # fine for $num3
} # fine if (substr($linea[$num2],-4) ==  "user" or...)
if (substr($linea[$num2],-8) ==  "password" or substr($linea[$num2],-9) ==  "password ") {
$parte = explode(" ",$linea[$num2+1]);
for ($num3 = 0 ; $num3 < count($parte) ; $num3++) {
if ($parte[$num3] != "") {
$PHPR_DB_PASS = str_replace("\"","",$parte[$num3]);
$PHPR_DB_PASS = str_replace("\'","",$PHPR_DB_PASS);
break;
} # fine if ($parte[$num3] != "")
} # fine for $num3
} # fine if (substr($linea[$num2],-4) ==  "password" or...)
} # fine for $num2
} # fine if (substr($linea,0,15) == "\$numconnessione")
if (substr($linea,0,14) == "dl(\"pgsql.so\")") $PHPR_LOAD_EXT = "SI";
} # fine for $num1
unlink("./dati/connessione_db.php");
$file_conn = fopen("./dati/dati_connessione.php","w+");
fwrite($file_conn,"<?php
\$PHPR_DB_TYPE = \"postgresql\";
\$PHPR_DB_NAME = \"$PHPR_DB_NAME\";
\$PHPR_DB_HOST = \"$PHPR_DB_HOST\";
\$PHPR_DB_PORT = \"$PHPR_DB_PORT\";
\$PHPR_DB_USER = \"$PHPR_DB_USER\";
\$PHPR_DB_PASS = \"$PHPR_DB_PASS\";
\$PHPR_LOAD_EXT = \"$PHPR_LOAD_EXT\";
?>");
fclose($file_conn);
# cambio idappartamenti da text a varchar(100) in appartamenti, $tableprenota e $tableregole
pg_exec("alter table appartamenti rename to appart");
pg_exec("drop index appartamenti_pkey");
pg_exec("alter table appart rename column idappartamenti to idappart");
pg_exec("alter table appart add column idappartamenti varchar(100)");
$appartamenti = pg_exec("select * from appart");
$num_appartamenti = pg_numrows($appartamenti);
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$idapp = pg_result($appartamenti,$num1,idappart);
pg_exec("update appart set idappartamenti = '$idapp' where idappart = '$idapp'");
} # fine for $num1
pg_exec("create table appartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, commento text )");
pg_exec("insert into appartamenti select idappartamenti,numpiano,maxoccupanti,numcasa,app_vicini,priorita,commento from appart");
pg_exec("drop table appart");
$anni = pg_exec("select * from anni order by idanni");
$num_anni = pg_numrows($anni);
for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
$anno_cambia = pg_result($anni,$num1,idanni);
$tableprenota = prenota . $anno_cambia;
$tableprenota_temp = pren . $anno_cambia;
pg_exec("alter table $tableprenota rename to $tableprenota_temp");
pg_exec("drop index $tableprenota"."_pkey");
pg_exec("alter table $tableprenota_temp rename column idappartamenti to idappart");
pg_exec("alter table $tableprenota_temp add column idappartamenti varchar(100)");
$prenotazioni = pg_exec("select * from $tableprenota_temp");
$num_prenotazioni = pg_numrows($prenotazioni);
for ($num2 = 0 ; $num2 < $num_prenotazioni ; $num2 = $num2 + 1) {
$idprenota = pg_result($prenotazioni,$num2,idprenota);
$idapp = pg_result($prenotazioni,$num2,idappart);
pg_exec("update $tableprenota_temp set idappartamenti = '$idapp' where idprenota = '$idprenota'");
} # fine for $num2
pg_exec("create table $tableprenota (idprenota integer primary key, idclienti integer, idappartamenti varchar(100), iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text, tariffa text, costiaggiuntivi text, sconto float8, tariffa_tot float8, caparra float8, pagato float8, commento text, conferma varchar(4), datainserimento datetime, hostinserimento varchar(50), data_modifica datetime )");
pg_exec("insert into $tableprenota select idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna,tariffa,costiaggiuntivi,sconto,tariffa_tot,caparra,pagato,commento,conferma,datainserimento,hostinserimento,data_modifica from $tableprenota_temp");
pg_exec("drop table $tableprenota_temp");
$tableregole = regole . $anno_cambia;
$tableregole_temp = reg . $anno_cambia;
pg_exec("alter table $tableregole rename to $tableregole_temp");
pg_exec("alter table $tableregole_temp rename column app_agenzia to app_ag");
pg_exec("alter table $tableregole_temp add column app_agenzia varchar(100)");
$regole = pg_exec("select * from $tableregole_temp");
$num_regole = pg_numrows($regole);
for ($num2 = 0 ; $num2 < $num_regole ; $num2 = $num2 + 1) {
$idregole = pg_result($regole,$num2,idregole);
$app_ag = pg_result($regole,$num2,app_ag);
pg_exec("update $tableregole_temp set app_agenzia = '$app_ag' where idregole = '$idregole'");
} # fine for $num2
pg_exec("create table $tableregole (idregole integer, app_agenzia varchar(100), tariffa_per_app text, iddatainizio integer, iddatafine integer, motivazione text)");
pg_exec("insert into $tableregole select idregole,app_agenzia,tariffa_per_app,iddatainizio,iddatafine,motivazione from $tableregole_temp");
pg_exec("drop table $tableregole_temp");
} # fine for $num1
pg_exec("alter table personalizza rename to pers");
pg_exec("drop index personalizza_pkey");
pg_exec("alter table pers rename column idpersonalizza to idpers");
pg_exec("alter table pers add column idpersonalizza varchar(50)");
$personalizzazioni = pg_exec("select * from pers");
$num_personalizzazioni = pg_numrows($personalizzazioni);
for ($num1 = 0 ; $num1 < $num_personalizzazioni ; $num1 = $num1 + 1) {
$idpers = pg_result($personalizzazioni,$num1,idpers);
pg_exec("update pers set idpersonalizza = '$idpers' where idpers = '$idpers'");
} # fine for $num1
pg_exec("create table personalizza (idpersonalizza varchar(50) primary key, valpersonalizza text, valpersonalizza_num integer)");
pg_exec("insert into personalizza select idpersonalizza,valpersonalizza,valpersonalizza_num from pers");
pg_exec("drop table pers");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_righe_tab_tutte_prenota',200)");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_righe_tab_storia_soldi',200)");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza) values ('stile_data','europa')");
pg_exec("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_righe_tab_tutti_clienti','200')");
pg_exec("set datestyle to 'iso'");
for ($num_a = 0 ; $num_a < $num_anni ; $num_a++) {
$anno_cambia = pg_result($anni,$num_a,idanni);
$tableperiodi = "periodi" . $anno_cambia;
$tipo_periodi = pg_exec("select * from anni where idanni = $anno_cambia");
$tipo_periodi = pg_result($tipo_periodi,0,tipo_periodi);
if ($tipo_periodi == "g") $aggiungi_giorni = 1;
else $aggiungi_giorni = 7;
$periodi = pg_exec("select * from $tableperiodi order by idperiodi");
$num_periodi = pg_numrows($periodi);
$numgiorno = pg_result($periodi,0,datainizio);
$numgiorno = explode("-",$numgiorno);
$mese_ini = $numgiorno[1];
$numgiorno = $numgiorno[2];
$fileaperto = fopen("dati/selectperiodi$anno_cambia.php","w+");
flock($fileaperto,2);
fwrite($fileaperto,"<?php 
echo \"
");
for ($num1 = 0 ; $num1 < $num_periodi ; $num1 = $num1 + 1) {
$datainizio = date("Y-m-d" , mktime(0,0,0,$mese_ini,$numgiorno,$anno_cambia));
$nome_giorno = date("D" , mktime(0,0,0,$mese_ini,$numgiorno,$anno_cambia));
$numgiorno = $numgiorno + $aggiungi_giorni;
if ($tipo_periodi == "g") {
if ($nome_giorno == "Sun") $nome_giorno = mex(" Do",$pag);
if ($nome_giorno == "Mon") $nome_giorno = mex(" Lu",$pag);
if ($nome_giorno == "Tue") $nome_giorno = mex(" Ma",$pag);
if ($nome_giorno == "Wed") $nome_giorno = mex(" Me",$pag);
if ($nome_giorno == "Thu") $nome_giorno = mex(" Gi",$pag);
if ($nome_giorno == "Fri") $nome_giorno = mex(" Ve",$pag);
if ($nome_giorno == "Sat") $nome_giorno = mex(" Sa",$pag);
} # fine if ($tipo_periodi == "g")
else $nome_giorno = "";
$nome_mese = substr($datainizio,5,2);
if ($nome_mese == "01") $nome_mese = mex("Gen",$pag);
if ($nome_mese == "02") $nome_mese = mex("Feb",$pag);
if ($nome_mese == "03") $nome_mese = mex("Mar",$pag);
if ($nome_mese == "04") $nome_mese = mex("Apr",$pag);
if ($nome_mese == "05") $nome_mese = mex("Mag",$pag);
if ($nome_mese == "06") $nome_mese = mex("Giu",$pag);
if ($nome_mese == "07") $nome_mese = mex("Lug",$pag);
if ($nome_mese == "08") $nome_mese = mex("Ago",$pag);
if ($nome_mese == "09") $nome_mese = mex("Set",$pag);
if ($nome_mese == "10") $nome_mese = mex("Ott",$pag);
if ($nome_mese == "11") $nome_mese = mex("Nov",$pag);
if ($nome_mese == "12") $nome_mese = mex("Dic",$pag);
$numero_giorno = substr($datainizio,8,2);
$numero_anno = substr($datainizio,0,4);
fwrite($fileaperto,"<option value=\\\"$datainizio\\\">$nome_mese $numero_giorno$nome_giorno, $numero_anno</option>
");
} # fine for $num1
$datafine = date("Y-m-d" , mktime(0,0,0,$mese_ini,$numgiorno,$anno_cambia));
$nome_mese = substr($datafine,5,2);
if ($nome_mese == "01") $nome_mese = mex("Gen",$pag);
if ($nome_mese == "02") $nome_mese = mex("Feb",$pag);
if ($nome_mese == "03") $nome_mese = mex("Mar",$pag);
if ($nome_mese == "04") $nome_mese = mex("Apr",$pag);
if ($nome_mese == "05") $nome_mese = mex("Mag",$pag);
if ($nome_mese == "06") $nome_mese = mex("Giu",$pag);
if ($nome_mese == "07") $nome_mese = mex("Lug",$pag);
if ($nome_mese == "08") $nome_mese = mex("Ago",$pag);
if ($nome_mese == "09") $nome_mese = mex("Set",$pag);
if ($nome_mese == "10") $nome_mese = mex("Ott",$pag);
if ($nome_mese == "11") $nome_mese = mex("Nov",$pag);
if ($nome_mese == "12") $nome_mese = mex("Dic",$pag);
$numero_giorno = substr($datafine,8,2);
$numero_anno = substr($datafine,0,4);
fwrite($fileaperto,"<option value=\\\"$datafine\\\">$nome_mese $numero_giorno, $numero_anno</option>
");
fwrite($fileaperto,"\";
?>");
flock($fileaperto,3);
fclose($fileaperto);
copy ("dati/selectperiodi$anno_cambia.php","dati/selperiodimenu$anno_cambia.php");
} # fine for $num_a
} # fine if ($versione_corrente < "0.30")

if ($versione_corrente < "0.31") {
$aggiornato = "SI";
$anni = esegui_query("select * from anni order by idanni");
$num_anni = numlin_query($anni);
for ($num_a = 0 ; $num_a < $num_anni ; $num_a++) {
$anno_cambia = risul_query($anni,$num_a,idanni);
$tablenometariffe = ntariffe . $anno_cambia;
$idntariffe = esegui_query("select max(idntariffe) from $tablenometariffe");
$idntariffe = risul_query($idntariffe,0,0) + 1;
esegui_query("update $tablenometariffe set regole = '$idntariffe' where idntariffe = 1");
} # fine for $num_a
} # fine if ($versione_corrente < "0.31")

if ($versione_corrente < "0.32") {
$aggiornato = "SI";
include("./dati/dati_connessione.php");
$file_conn = fopen("./dati/dati_connessione.php","w+");
fwrite($file_conn,"<?php
\$PHPR_DB_TYPE = \"$PHPR_DB_TYPE\";
\$PHPR_DB_NAME = \"$PHPR_DB_NAME\";
\$PHPR_DB_HOST = \"$PHPR_DB_HOST\";
\$PHPR_DB_PORT = \"$PHPR_DB_PORT\";
\$PHPR_DB_USER = \"$PHPR_DB_USER\";
\$PHPR_DB_PASS = \"$PHPR_DB_PASS\";
\$PHPR_LOAD_EXT = \"$PHPR_LOAD_EXT\";
\$PHPR_TAB_PRE = \"\";
?>");
fclose($file_conn);
$PHPR_TAB_PRE = "";
$col_tab_tutte_prenota = esegui_query("select * from personalizza where idpersonalizza = 'col_tab_tutte_prenota'");
$col_tab_tutte_prenota = risul_query($col_tab_tutte_prenota,0,valpersonalizza);
if ($col_tab_tutte_prenota) $col_tab_tutte_prenota .= "#@&tc";
else $col_tab_tutte_prenota = "tc";
esegui_query("update personalizza set valpersonalizza = '$col_tab_tutte_prenota' where idpersonalizza = 'col_tab_tutte_prenota'");
} # fine if ($versione_corrente < "0.32")

if ($versione_corrente < "0.33") {
$aggiornato = "SI";
} # fine if ($versione_corrente < "0.33")

if ($versione_corrente < "0.40") {
$aggiornato = "SI";
esegui_query("create table ".$PHPR_TAB_PRE."utenti (idutenti integer primary key, nome_utente text, password text, tipo_pass varchar(1) )");
esegui_query("insert into ".$PHPR_TAB_PRE."utenti (idutenti, nome_utente, tipo_pass) values (1,'admin','n')");
esegui_query("create table ".$PHPR_TAB_PRE."privilegi (idutente integer, anno integer, regole1_consentite text, tariffe_consentite text, costi_agg_consentiti text, contratti_consentiti text, priv_ins_prenota varchar(20), priv_mod_prenota varchar(35), priv_mod_pers varchar(15), priv_ins_clienti varchar(10), prefisso_clienti text, priv_ins_costi varchar(5), priv_vedi_tab varchar(30), priv_ins_tariffe varchar(10), priv_ins_regole varchar(10) )");
esegui_query("create table ".$PHPR_TAB_PRE."sessioni (idsessioni varchar(30) primary key, idutente integer, indirizzo_ip text, user_agent text, ultimo_accesso datetime)");
esegui_query("create table ".$PHPR_TAB_PRE."transazioni (idtransazioni varchar(30) primary key, idsessione varchar(30), tipo_transazione varchar(5), anno integer, spostamenti text, dati_transazione1 text, dati_transazione2 text, dati_transazione3 text, dati_transazione4 text, dati_transazione5 text, dati_transazione6 text, dati_transazione7 text, dati_transazione8 text, dati_transazione9 text, dati_transazione10 text, dati_transazione11 text, dati_transazione12 text, dati_transazione13 text, dati_transazione14 text, dati_transazione15 text, dati_transazione16 text, dati_transazione17 text, dati_transazione18 text, ultimo_accesso datetime)");
esegui_query("alter table ".$PHPR_TAB_PRE."personalizza rename to ".$PHPR_TAB_PRE."pers");
esegui_query("create table ".$PHPR_TAB_PRE."personalizza (idpersonalizza varchar(50) not null, idutente integer, valpersonalizza text, valpersonalizza_num integer)");
$pers = esegui_query("select * from ".$PHPR_TAB_PRE."pers");
for ($num1 = 0 ; $num1 < numlin_query($pers) ; $num1++) {
$idpersonalizza = risul_query($pers,$num1,idpersonalizza);
$valpersonalizza = risul_query($pers,$num1,valpersonalizza);
$valpersonalizza_num = risul_query($pers,$num1,valpersonalizza_num);
esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,valpersonalizza,valpersonalizza_num) values ('$idpersonalizza','$valpersonalizza','$valpersonalizza_num')");
} # fine for $num1
esegui_query("drop table ".$PHPR_TAB_PRE."pers");
esegui_query("update ".$PHPR_TAB_PRE."personalizza set idutente = '1'");
esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,idutente,valpersonalizza_num) values ('minuti_durata_sessione','1','90')");
esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,idutente,valpersonalizza_num) values ('ore_anticipa_periodo_corrente','1','0')");
esegui_query("alter table ".$PHPR_TAB_PRE."clienti add column utente_inserimento integer");
esegui_query("update ".$PHPR_TAB_PRE."clienti set utente_inserimento = '1'");
for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
$anno_mostra = risul_query($anni,$num1,idanni);
$tableprenota = $PHPR_TAB_PRE."prenota". $anno_mostra;
esegui_query("alter table $tableprenota add column utente_inserimento integer");
esegui_query("update $tableprenota set utente_inserimento = '1'");
$tablecosti = $PHPR_TAB_PRE."costi". $anno_mostra;
esegui_query("alter table $tablecosti add column utente_inserimento integer");
esegui_query("update $tablecosti set utente_inserimento = '1' where idcosti != '0'");
$tablesoldi = $PHPR_TAB_PRE."soldi". $anno_mostra;
esegui_query("alter table $tablesoldi add column utente_inserimento integer");
esegui_query("update $tablesoldi set utente_inserimento = '1'");
} # fine for $num1
include("./dati/lingua.php");
$fileaperto = fopen("dati/lingua.php","w+");
flock($fileaperto,2);
fwrite($fileaperto,"<?php
\$lingua[1] = \"$lingua\";
?>");
flock($fileaperto,3);
fclose($fileaperto);
for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
$anno_cambia = risul_query($anni,$num1,idanni);
rename("./dati/selectperiodi$anno_cambia.php","./dati/selectperiodi$anno_cambia.1.php");
rename("./dati/selperiodimenu$anno_cambia.php","./dati/selperiodimenu$anno_cambia.1.php");
} # fine for $num1
} # fine if ($versione_corrente < "0.40")

if ($versione_corrente < "0.41") {
$aggiornato = "SI";
for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
$anno_mostra = risul_query($anni,$num1,idanni);
$tableregole = $PHPR_TAB_PRE."regole".$anno_mostra;
esegui_query("alter table $tableregole add column tariffa_per_utente text");
$tablesoldi = $PHPR_TAB_PRE."soldi".$anno_mostra;
esegui_query("update $tablesoldi set utente_inserimento = '1' where utente_inserimento = '' or utente_inserimento is null");
} # fine for $num1
esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,idutente,valpersonalizza) values ('tutti_fissi','1','NO')");
} # fine if ($versione_corrente < "0.41")

if ($versione_corrente < "0.42") {
$aggiornato = "SI";
} # fine if ($versione_corrente < "0.42")

if ($versione_corrente < "0.43") {
$aggiornato = "SI";
} # fine if ($versione_corrente < "0.43")



echo "
<center>
PHP-RESIDENCE version 0.4.3, Copyright (C) 2001-2004 Marco M. F. De Santis<br>
Php-residence comes with ABSOLUTELY NO WARRANTY; <br>for details see the file 
<a href=\"COPYING\">COPYING</a>. <br> This is free software, and you are 
welcome to redistribute it<br>
 under certain conditions; see the  file 
<a href=\"COPYING\">COPYING</a> for details.<br>
</center><hr width=\"95%\">
<br>";
if ($aggiornato == "SI") {
esegui_query("update ".$PHPR_TAB_PRE."versioni set num_versione = '0.43' where idversioni = 1");
echo "<font size=+2>".mex("Database aggiornato alla versione",$pag)." <b>0.4.3</b>!<br></font>";
} # fine if ($aggiornato == "SI")
else { echo "<font size=+2>".mex("Niente da aggiornare",$pag).".<br></font>"; }

#pg_exec("commit");

echo "<center><br><form method=\"post\" action=\"inizio.php\">
<input type=\"submit\" name=\"indietro\" value=\"".mex("Vai al men principale",$pag)."\">
</form></center>";

?>

</body>
</html>
